#!/bin/bash
cp -f multivnc_server /usr/bin/.
cp -f multivnc_client /usr/bin/.
mkdir -p /etc/multivnc/
if [ ! -e /etc/multivnc/multivnc_server.conf ] ; then
  cp -f multivnc_server.conf /etc/multivnc/.
  chmod 666 /etc/multivnc/multivnc_server.conf
fi

cp -f src_server/po/ja.mo \
      /usr/share/locale/ja/LC_MESSAGES/multivnc_server.mo
cp -f src_client/po/ja.mo \
      /usr/share/locale/ja/LC_MESSAGES/multivnc_client.mo
cp -f src_server/po/zh_CN.mo \
      /usr/share/locale/zh_CN/LC_MESSAGES/multivnc_server.mo
cp -f src_client/po/zh_CN.mo \
      /usr/share/locale/zh_CN/LC_MESSAGES/multivnc_client.mo
cp -f src_server/po/vi.mo \
      /usr/share/locale/vi/LC_MESSAGES/multivnc_server.mo
cp -f src_client/po/vi.mo \
      /usr/share/locale/vi/LC_MESSAGES/multivnc_client.mo
cp -f src_server/po/ro.mo \
      /usr/share/locale/ro/LC_MESSAGES/multivnc_server.mo
cp -f src_client/po/ro.mo \
      /usr/share/locale/ro/LC_MESSAGES/multivnc_client.mo
echo "MultiVNC Install COMPLETE!"
